@@ -19,7 +19,9 @@ from .create_dataset import create_dataset
 from .encode_features import encode_features
 from .load_dataset import load_dataset
 
+
 __author__ = "Abien Fred Agarap"
+__version__ = "0.16.7"
 
 
 def list_datasets() -> str:
@@ -30,10 +32,14 @@ def list_datasets() -> str:
         "KMNIST",
         "SVHN",
         "CIFAR10",
-        "AG News" "20 Newsgroups",
+        "AG News",
+        "20 Newsgroups",
+        "IMDB",
+        "Yelp",
         "Malware Image",
         "Wisconsin Diagnostic Breast Cancer",
         "Binary COVID19",
         "Multi COVID19",
+        "USPS",
     ]
     return datasets
